@@ -1,72 +1,51 @@
-#!/usr/bin/env python
-# coding: utf-8
-
 """
     unittest for setup_utils
     ~~~~~~~~~~~~~~~~~~~~~~~~
 
-    https://code.google.com/p/python-creole/wiki/UseInSetup
+    https://github.com/jedie/python-creole/wiki/Use-In-Setup
 
-    :copyleft: 2011-2014 by python-creole team, see AUTHORS for more details.
+    :copyleft: 2011-2020 by python-creole team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
-
-from __future__ import division, absolute_import, print_function, unicode_literals
-
-import unittest
+import difflib
+import filecmp
 import os
-import warnings
-
-try:
-    import docutils
-    DOCUTILS = True
-except ImportError:
-    DOCUTILS = False
-
-import creole
-from creole.setup_utils import get_long_description
-from creole.tests.utils.base_unittest import BaseCreoleTest
-from creole.py3compat import BINARY_TYPE, PY3, TEXT_TYPE
+import shutil
 import tempfile
+from pathlib import Path
 
+from creole.setup_utils import get_long_description, update_creole_rst_readme
+from creole.tests.constants import CREOLE_PACKAGE_ROOT
+from creole.tests.utils.base_unittest import BaseCreoleTest
+from creole.tests.utils.utils import IsolatedFilesystem
 
-CREOLE_PACKAGE_ROOT = os.path.abspath(os.path.join(os.path.dirname(creole.__file__), ".."))
-TEST_README_DIR = os.path.abspath(os.path.dirname(__file__))
+TEST_README_DIR = Path(__file__).parent
 TEST_README_FILENAME = "test_README.creole"
 
 
-# TODO: Use @unittest.skipIf if python 2.6 will be not support anymore.
-# @unittest.skipIf(DOCUTILS == False, "docutils not installed.")
 class SetupUtilsTests(BaseCreoleTest):
-    def run(self, *args, **kwargs):
-        # TODO: Remove if python 2.6 will be not support anymore.
-        if DOCUTILS == False:
-            warnings.warn("Skip SetupUtilsTests, because 'docutils' not installed.")
-            return
-        return super(SetupUtilsTests, self).run(*args, **kwargs)
-
     def test_creole_package_path(self):
         self.assertTrue(
             os.path.isdir(CREOLE_PACKAGE_ROOT),
-            "CREOLE_PACKAGE_ROOT %r is not a existing direcotry!" % CREOLE_PACKAGE_ROOT
+            f"CREOLE_PACKAGE_ROOT {CREOLE_PACKAGE_ROOT!r} is not a existing direcotry!"
         )
         filepath = os.path.join(CREOLE_PACKAGE_ROOT, "README.creole")
         self.assertTrue(
             os.path.isfile(filepath),
-            "README file %r not found!" % filepath
+            f"README file {filepath!r} not found!"
         )
 
     def test_get_long_description_without_raise_errors(self):
         long_description = get_long_description(CREOLE_PACKAGE_ROOT, raise_errors=False)
-        self.assertIn("=====\nabout\n=====\n\n", long_description)
+        self.assertIn("===================\nabout python-creole\n===================\n\n", long_description)
         # Test created ReSt code
         from creole.rest_tools.clean_writer import rest2html
         html = rest2html(long_description)
-        self.assertIn("<h1>about</h1>\n", html)
+        self.assertIn("<h1>about python-creole</h1>\n", html)
 
     def test_get_long_description_with_raise_errors(self):
         long_description = get_long_description(CREOLE_PACKAGE_ROOT, raise_errors=True)
-        self.assertIn("=====\nabout\n=====\n\n", long_description)
+        self.assertIn("===================\nabout python-creole\n===================\n\n", long_description)
 
     def _tempfile(self, content):
         fd = tempfile.NamedTemporaryFile()
@@ -124,16 +103,47 @@ class SetupUtilsTests(BaseCreoleTest):
 
     def test_readme_encoding(self):
         long_description = get_long_description(TEST_README_DIR, filename=TEST_README_FILENAME, raise_errors=True)
-
-        if PY3:
-            self.assertTrue(isinstance(long_description, TEXT_TYPE))
-        else:
-            self.assertTrue(isinstance(long_description, BINARY_TYPE))
+        self.assertTrue(isinstance(long_description, str))
 
         txt = "German Umlaute: ä ö ü ß Ä Ö Ü"
-        if not PY3:
-            txt = txt.encode("utf-8")
         self.assertIn(txt, long_description)
 
-if __name__ == '__main__':
-    unittest.main()
+
+def test_update_rst_readme():
+    with IsolatedFilesystem(prefix="temp_dir_prefix"):
+        old_rest_readme_path = Path(Path().cwd(), 'README.rst')
+        shutil.copy(
+            Path(CREOLE_PACKAGE_ROOT, 'README.rst'),
+            old_rest_readme_path
+        )
+        try:
+            rest_readme_path = update_creole_rst_readme()
+            assert str(rest_readme_path.relative_to(CREOLE_PACKAGE_ROOT)) == 'README.rst'
+
+            if filecmp.cmp(rest_readme_path, old_rest_readme_path, shallow=False) is True:
+                return
+
+            # On CI the file modification time maybe not the same.
+            # So skip the last line and compare again.
+
+            with old_rest_readme_path.open('r') as f:
+                from_file = [line.rstrip() for line in f][:-1]
+
+            with rest_readme_path.open('r') as f:
+                to_file = [line.rstrip() for line in f][:-1]
+
+            if from_file == to_file:
+                return
+
+            diff = '\n'.join(
+                line
+                for line in difflib.Differ().compare(from_file, to_file)
+                if line[0] != ' '
+            )
+            raise AssertionError(f'README.rst is not up-to-date:\n{diff}')
+        finally:
+            # restore the origin file
+            shutil.copy(
+                old_rest_readme_path,
+                Path(CREOLE_PACKAGE_ROOT, 'README.rst'),
+            )
